@@ -541,25 +541,40 @@ sheet_object_get_sheet (SheetObject const *so)
 	return so->sheet;
 }
 
+static void
+cb_create_views_helper (GPtrArray *sos, gboolean qfreeze)
+{
+	Sheet const *last_sheet = NULL;
+	unsigned ui, l = sos->len;
+	for (ui = 0; ui < l; ui++) {
+		SheetObject *so = g_ptr_array_index (sos, ui);
+		if (so->sheet == last_sheet) {
+			// Avoid excessive duplicate freezes.  This is
+			// not essential, but helps with debugging.
+			continue;
+		}
+		last_sheet = so->sheet;
+		sheet_freeze_object_views (so->sheet, qfreeze);
+	}
+}
+
 static gboolean
 cb_create_views (void)
 {
-	int pass;
+	unsigned ui, l = so_create_view_sos->len;
 
-	for (pass = 1; pass <= 3; pass++) {
-		unsigned ui, l = so_create_view_sos->len;
-		for (ui = 0; ui < l; ui++) {
-			SheetObject *so = g_ptr_array_index (so_create_view_sos, ui);
-			SHEET_FOREACH_CONTROL
-				(so->sheet, view, control,
-				 if (pass == 2)
-					 sc_object_create_view (control, so);
-				 else
-					 sc_freeze_object_view (control, pass == 1);
-					);
-		}
+	cb_create_views_helper (so_create_view_sos, TRUE);
+
+	for (ui = 0; ui < l; ui++) {
+		SheetObject *so = g_ptr_array_index (so_create_view_sos, ui);
+		SHEET_FOREACH_CONTROL
+			(so->sheet, view, control,
+			 sc_object_create_view (control, so););
 	}
 	g_ptr_array_set_size (so_create_view_sos, 0);
+
+	cb_create_views_helper (so_create_view_sos, FALSE);
+
 	so_create_view_src = 0;
 	return FALSE;
 }
@@ -1226,6 +1241,7 @@ sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t,
 		     GOUndo **pundo)
 {
 	GSList *ptr, *next;
+	gboolean any = FALSE;
 
 	g_return_if_fail (IS_SHEET (sheet));
 
@@ -1235,10 +1251,18 @@ sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t,
 		if ((t == G_TYPE_NONE && G_OBJECT_TYPE (obj) != GNM_FILTER_COMBO_TYPE)
 		    || t == G_OBJECT_TYPE (obj)) {
 			SheetObject *so = GNM_SO (obj);
-			if (r == NULL || range_contained (&so->anchor.cell_bound, r))
+			if (r == NULL || range_contained (&so->anchor.cell_bound, r)) {
+				if (!any) {
+					sheet_freeze_object_views (sheet, TRUE);
+					any = TRUE;
+				}
 				clear_sheet (so, pundo);
+			}
 		}
 	}
+
+	if (any)
+		sheet_freeze_object_views (sheet, FALSE);
 }
 
 /**
