@@ -1,7 +1,7 @@
 #ifndef AUTO_CORRECT_H
 #define AUTO_CORRECT_H
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 
 char    *autocorrect_tool	 (char const *input);
 
